<?php

namespace Drupal\farm_multitenant\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines access logic for logs based on group membership.
 */
class AccessControlHandlerLog extends AccessControlHandlerBase {
  /**
   * {@inheritdoc}
   */
  public function createAccess($entity_bundle = NULL, ?AccountInterface $account = NULL, array $context = [], $return_as_object = FALSE) {
    $account = $this->prepareUser($account);
    $permission = 'create ' . $entity_bundle . ' log';
    if ($account && $account->hasPermission($permission)) {
      return $return_as_object ? AccessResult::allowed() : AccessResult::allowed()->isAllowed();
    }

    return parent::createAccess($entity_bundle, $account, $context, $return_as_object);
  }

  /**
   * {@inheritdoc}
   */
  protected function checkGroupAccess(EntityInterface $entity, AccountInterface $account) {
    // Ensure the entity is a log.
    if ($entity->getEntityTypeId() !== 'log') {
      return AccessResult::forbidden();
    }

    // Get the asset referenced by the log.
    if ($entity->hasField('asset') && !$entity->get('asset')->isEmpty()) {
      $asset = $entity->get('asset')->entity;
    }
    else {
      return AccessResult::forbidden();
    }

    // Delegate to the parent class to check access for the asset.
    return parent::checkGroupAccess($asset, $account);
  }

}
